Learn R Programming

tteICE (version 1.1.2)

basehaz.tteICE: Baseline hazards of 'tteICE' objects

Description

This function extracts the baseline cumulative hazards in the survival models

Usage

basehaz.tteICE(object)

Value

A data frame of baseline cumulative hazards in the working Kaplan-Meier or Cox models, stratified by treatment groups. The first column is time, the following columns are baseline cumulative hazards.

Arguments

object

A fitted object returned by the function tteICE, surv.tteICE, or scr.tteICE.