This function estimates the potential cumulative incidence function based on efficient influence functions using principal stratum strategy (competing risks data structure). Cox models are employed for survival models. The estimand is defined in a subpopulation where intercurrent events would never occur regardless of treatment conditions.
surv.principal.eff(A, Time, cstatus, X = NULL)A list including
Time points in the treated group.
Time points in the control group.
Estimated cumulative incidence function in the treated group.
Estimated cumulative incidence function in the control group.
Standard error of the estimated cumulative incidence function in the treated group.
Standard error of the estimated cumulative incidence function in the control group.
Time points in both groups.
Estimated treatment effect (difference in cumulative incidence functions).
Standard error of the estimated treatment effect.
P value of testing the treatment effect based on the efficient influence function of the restricted mean survival time lost by the end of study.
Coefficients of covariates in the working Cox models for each event.
P values of the proportional hazards assumption in the working Cox models for each event.
Baseline cumulative hazards in the working Cox models.
Treatment indicator, 1 for treatment and 0 for control.
Time to event.
Indicator of event, 1 for the primary event, 2 for the intercurrent event, 0 for censoring.
Baseline covariates.
surv.principal, surv.tteICE