Skip to contents

This function opens the RShiny app for tteICE. RShiny application can be used for generating plots and basic analysis results. It provides a point-and-click interface, so users can obtain results without writing R code directly.

Usage

tteICEShiny()

Value

Rshiny interface

Examples

if(interactive() && requireNamespace("shiny", quietly = TRUE)){
  tteICEShiny()
}