Learn R Programming

tteICE (version 1.1.2)

bshaz: S3 method of baseline hazards

Description

This function extracts the baseline cumulative hazards in the survival models

Usage

bshaz(x)

Value

A data frame of baseline cumulative hazards in the working Kaplan-Meier or Cox models, stratified by treatment groups from the model object.

Arguments

x

A fitted object returned by the function tteICE, surv.tteICE, or scr.tteICE.