This function nonparametrically estimates the potential cumulative incidence function using composite variable strategy (competing risks data structure). This strategy adopts the first occurrence of either the intermediate or primary event as the event of interest.
surv.composite(A, Time, cstatus, weights = rep(1, length(A)))A list including
Time points in the treated group.
Time points in the control group.
Estimated cumulative incidence function in the treated group.
Estimated cumulative incidence function in the control group.
Standard error of the estimated cumulative incidence function in the treated group.
Standard error of the estimated cumulative incidence function in the control group.
Time points in both groups.
Estimated treatment effect (difference in cumulative incidence functions).
Standard error of the estimated treatment effect.
P value of testing the treatment effect based on logrank test.
Treatment indicator, 1 for treatment and 0 for control.
Time to event.
Indicator of event, 1 for the primary event, 2 for the intercurrent event, 0 for censoring.
Weight for each subject.
surv.composite.eff, surv.tteICE