Learn R Programming

tteICE (version 1.1.0)

tteICEShiny: Shiny app for tteICE

Description

This function opens the RShiny app for tteICE. RShiny application can be used for generating plots and basic analysis results. It provides a point-and-click interface, so users can obtain results without writing R code directly.

Usage

tteICEShiny()

Arguments

Value

Rshiny interface

Examples

Run this code
# \donttest{
if(interactive()){
  tteICEShiny()
}
# }

Run the code above in your browser using DataLab