powered by
This function opens the RShiny app for tteICE. RShiny application can be used for generating plots and basic analysis results. It provides a point-and-click interface, so users can obtain results without writing R code directly.
tteICEShiny()
Rshiny interface
# \donttest{ if(interactive()){ tteICEShiny() } # }
Run the code above in your browser using DataLab