This function checks the proportional hazards assumption in the Cox model using Schoenfeld residuals. This function only return results for strategies based on efficient influence functions.
This function checks the proportional hazards assumption in the Cox model using Schoenfeld residuals. This function only return results for strategies based on efficient influence functions.